# Shutyl

Shutyl is a file conversion and copying tool.

Shutyl's origins are in generating ogg files from flac and wav files,
while cloning (rather than reconverting) mp3 files. Project goals are
a bit more ambitious with a custom computer language to define
conversions, and support for more types of conersions.
